@@ -1,5 +1,5 @@
 from django.conf.urls import url, patterns
-from studiogdo.views import LoginView, AccueilView
+from studiogdo.pip.views import LoginView, AccueilView
 
 urlpatterns = patterns('',
     url(r'^$', view=LoginView.as_view(), name="login"),
